"use client"

import { createContext, useContext, useState, useEffect, type ReactNode } from "react"
import { getLocalContent, updateLocalContent } from "../utils/local-storage-adapter"

interface ContentContextType {
  content: any
  isLoading: boolean
  updateContent: (section: string, data: any) => void
  saveContent: () => Promise<boolean>
}

const ContentContext = createContext<ContentContextType | undefined>(undefined)

export function ContentProvider({ children }: { children: ReactNode }) {
  const [content, setContent] = useState<any>(null)
  const [isLoading, setIsLoading] = useState(true)

  useEffect(() => {
    // First try to fetch from API
    async function fetchContent() {
      try {
        const response = await fetch("/api/content")

        if (!response.ok) {
          throw new Error(`HTTP error! Status: ${response.status}`)
        }

        const data = await response.json()
        setContent(data)
        // Also update local storage as a backup
        updateLocalContent(data)
      } catch (error) {
        console.warn("Error fetching from API, falling back to local storage:", error)
        // Fallback to local storage
        const localContent = getLocalContent()
        setContent(localContent)
      } finally {
        setIsLoading(false)
      }
    }

    fetchContent()
  }, [])

  const updateContent = (section: string, data: any) => {
    setContent((prevContent: any) => ({
      ...prevContent,
      [section]: data,
    }))
  }

  const saveContent = async (): Promise<boolean> => {
    try {
      // First try to save to API
      const apiResponse = await fetch("/api/content", {
        method: "PUT",
        headers: {
          "Content-Type": "application/json",
        },
        body: JSON.stringify({
          section: "all",
          data: content,
        }),
      })

      if (!apiResponse.ok) {
        throw new Error("API save failed")
      }

      // Also update local storage as a backup
      updateLocalContent(content)
      return true
    } catch (error) {
      console.warn("Error saving to API, saving to local storage only:", error)
      // Fallback to local storage
      updateLocalContent(content)
      return false
    }
  }

  return (
    <ContentContext.Provider value={{ content, isLoading, updateContent, saveContent }}>
      {children}
    </ContentContext.Provider>
  )
}

export function useContent() {
  const context = useContext(ContentContext)
  if (context === undefined) {
    throw new Error("useContent must be used within a ContentProvider")
  }
  return context
}

